
plot.accel = function(Object, pdf_out = TRUE, lgnd=TRUE, dir_plot = c(), tz="GMT", ...)
{
	visual = Object$visual
	summary_sleep = ChangeTimeVar(Object$summary_sleep, col_idx=c(6:7, 15:16))
	id = unique(summary_sleep$id)
	Dat_list = Object$dat
	n_wear = max(summary_sleep$wear_day)
	if(visual==FALSE){
		print("Object has no data for visualization.")
	}else{
		if(pdf_out == TRUE) pdf(paste(dir_plot, "plot", id, ".pdf", sep=""), height=4, width=7)
			for(d in 1:n_wear){
			
				idx_wear_day = which(summary_sleep$wear_day == d)
				n_sleep = length(idx_wear_day)
				valid_accel = unique(summary_sleep$valid_accel[idx_wear_day])
				n_overlap = unique(summary_sleep$n_sleep[idx_wear_day])
				par(mfrow = c(1,1), mar=c(5.1,4.1,4.1,4.1))
				plot(Dat_list[[d]][,1], Dat_list[[d]][,2], type="n", col="cornflowerblue",  xaxt="n",...) 
					 
				time_char1 = matrix(unlist(strsplit(as.character(Dat_list[[d]][,1]), " ")), ncol=2, byrow=TRUE)[,2]
				time_char2 = substr(time_char1, 1, 5)
				n_dat = nrow(Dat_list[[d]])
				idx_select = seq(1, n_dat, by=120)
				axis(1, at=as.numeric(Dat_list[[d]][,1][idx_select]), labels=time_char2[idx_select], las=1)

				lines(Dat_list[[d]][,1], Dat_list[[d]][,2], col=rgb(0, 0, 1, alpha=0.4))

				abline(v=as.numeric(summary_sleep$SI_bed[idx_wear_day[1]]), lty=2, col="red")
				abline(v=as.numeric(summary_sleep$SI_wake[idx_wear_day[1]]), lty=2, col="red")				 
				diary_t_bed = strftime(summary_sleep$SI_bed[idx_wear_day[1]], format="%H:%M:%S", tz=tz)
				diary_t_wake = strftime(summary_sleep$SI_wake[idx_wear_day[1]], format="%H:%M:%S", tz=tz)
				title(paste(wday(Dat_list[[d]][1,1], label=TRUE), "to", wday(Dat_list[[d]][n_dat,1], label=TRUE)))
				
				if(valid_accel & n_overlap > 0){			
					idx_bed = which(Dat_list[[d]][,1] %in% summary_sleep$ts_start[idx_wear_day])
					idx_wake = which(Dat_list[[d]][,1] %in% summary_sleep$ts_end[idx_wear_day])
					
					for(j in 1:n_sleep){
						idx_sleep = idx_bed[j]:idx_wake[j]						
						for(j in idx_sleep) abline(v=Dat_list[[d]][j,1], col=rgb(red=1, 0, 0, alpha=.05), lwd=2)
					}
					
					lines(Dat_list[[d]][,1], Dat_list[[d]][,3])
					df = summary_sleep$df[idx_wear_day[1]]
					if(lgnd == TRUE){
						lgd= lgd= c("Estimated sleep Interval(s)","Provided sleep interval")
						legend("topright", lgd, lty=c(0,2), pch=c(15, -1), col=c("pink", "red"), bty="n", cex=.8)
					}		
					accel_t_bed = strftime(summary_sleep$ts_start[idx_wear_day[1]], format="%H:%M:%S", tz=tz)
					accel_t_wake = strftime(summary_sleep$ts_end[idx_wear_day[n_sleep]], format="%H:%M:%S", tz=tz)	

					lgd2 = c(paste("Provided-Bed: ", diary_t_bed ,", Wake: ", diary_t_wake, sep=""),
							 paste("Estimated-Bed: ", accel_t_bed  ,", Wake: ",accel_t_wake, sep=""))

				}else if(valid_accel & n_overlap == 0){
					lgd2 = c(paste("Provided-Bed: ", diary_t_bed ,", Wake: ", diary_t_wake, sep=""),
							 paste("Accel-Bed & Wake: cannot estimate"))	
				}else{
					lgd2 = c(paste("Provided-Bed: ", diary_t_bed ,", Wake: ", diary_t_wake, sep=""),
							 paste("Accel-Bed & Wake: possibly include non-wear data"))					
				}
				if(lgnd==TRUE) legend("topleft", lgd2, bty="n", cex=.8)
				
			}
			
		if(pdf_out == TRUE) dev.off()
	}
}

lines.add = function(Object, days = 1, col_rgb=rgb(red=0, green=0, blue=1, alpha=.05), col_fit="grey", ...)
{
	visual = Object$visual
	summary_sleep = ChangeTimeVar(Object$summary_sleep, col_idx=c(7:8))
	id = unique(summary_sleep$id)
	Dat_list = Object$dat
	d = days
	if(visual==FALSE){
		print("Object has no data for visualization.")
	}else{
		idx_wear_day = which(summary_sleep$wear_day == d)
		n_sleep = length(idx_wear_day)
		valid_accel = unique(summary_sleep$valid_accel[idx_wear_day])
		if(valid_accel){			
			idx_bed = which(Dat_list[[d]][,1] %in% summary_sleep$ts_start[idx_wear_day])
			idx_wake = which(Dat_list[[d]][,1] %in% summary_sleep$ts_end[idx_wear_day])
			
			for(j in 1:n_sleep){
				idx_sleep = idx_bed[j]:idx_wake[j]						
				for(j in idx_sleep) lines(rep(Dat_list[[d]][j,1],2), c(0, 2), col=col_rgb, lwd=2)
			}
			lines(Dat_list[[d]][,1], Dat_list[[d]][,3], col=col_fit, ...)
		}
	}
}
	

plot.eachday = function(Object, lgnd=TRUE, main = TRUE, days = 1, alpha1 = .4, alpha2 = .05, tz="GMT",...)
{
	visual = Object$visual
	summary_sleep = Object$summary_sleep
	summary_sleep = ChangeTimeVar(Object$summary_sleep, col_idx=c(6:7,15:16))
	id = unique(summary_sleep$id)
	Dat = ChangeTimeVar(Object$dat[[1]], col_idx=c(1))
	d = days
	if(visual==FALSE){
		print("Object has no data for visualization.")
	}else{
			
		idx_wear_day = which(summary_sleep$wear_day > 0)
		n_sleep = length(idx_wear_day)
		valid_accel = unique(summary_sleep$valid_accel[idx_wear_day])
		n_overlap = unique(summary_sleep$n_sleep[idx_wear_day])
		par(mfrow = c(1,1), mar=c(5.1,4.1,4.1,4.1))
		plot(Dat[,1], Dat[,2], type="n", col="cornflowerblue",  xaxt="n",...) 
			 
		time_char1 = matrix(unlist(strsplit(as.character(Dat[,1]), " ")), ncol=2, byrow=TRUE)[,2]
		time_char2 = substr(time_char1, 1, 5)
		n_dat = nrow(Dat)
		idx_select = seq(1, n_dat, by=120)
		axis(1, at=as.numeric(Dat[,1][idx_select]), labels=time_char2[idx_select], las=1)

		lines(Dat[,1], Dat[,2], col=rgb(0, 0, 1, alpha=alpha1))

		abline(v=as.numeric(summary_sleep$SI_bed[idx_wear_day[1]]), lty=2, col="red")
		abline(v=as.numeric(summary_sleep$SI_wake[idx_wear_day[1]]), lty=2, col="red")				 
		diary_t_bed = strftime(summary_sleep$SI_bed[idx_wear_day[1]], format="%H:%M:%S", tz=tz)
		diary_t_wake = strftime(summary_sleep$SI_wake[idx_wear_day[1]], format="%H:%M:%S", tz=tz)
		if(main== TRUE) title(paste(wday(Dat[1,1], label=TRUE), "to", wday(Dat[n_dat,1], label=TRUE)))
		
		if(valid_accel & n_overlap > 0){			
			idx_bed = which(Dat[,1] %in% summary_sleep$ts_start[idx_wear_day])
			idx_wake = which(Dat[,1] %in% summary_sleep$ts_end[idx_wear_day])
			
			for(j in 1:n_sleep){
				idx_sleep = idx_bed[j]:idx_wake[j]						
				for(j in idx_sleep) abline(v=Dat[j,1], col=rgb(red=1, 0, 0, alpha=alpha2), lwd=2)
			}
			
			lines(Dat[,1], Dat[,3])
			df = summary_sleep$df[idx_wear_day[1]]
			if(lgnd == TRUE){
				lgd= c("Estimated sleep Interval(s)","Provided sleep interval")
				legend("topright", lgd, lty=c(0,2), pch=c(15, -1), col=c("pink", "red"), bty="n", cex=.8)
			}		
			accel_t_bed = strftime(summary_sleep$ts_start[idx_wear_day[1]], format="%H:%M:%S", tz=tz)
			accel_t_wake = strftime(summary_sleep$ts_end[idx_wear_day[n_sleep]], format="%H:%M:%S", tz=tz)	

			lgd2 = c(paste("Provided-Bed: ", diary_t_bed ,", Wake: ", diary_t_wake, sep=""),
					 paste("Estimated-Bed: ", accel_t_bed  ,", Wake: ",accel_t_wake, sep=""))

		}else if(valid_accel & n_overlap == 0){
			lgd2 = c(paste("Provided-Bed: ", diary_t_bed ,", Wake: ", diary_t_wake, sep=""),
					 paste("Accel-Bed & Wake: cannot estimate"))	
		}else{
			lgd2 = c(paste("Provided-Bed: ", diary_t_bed ,", Wake: ", diary_t_wake, sep=""),
					 paste("Accel-Bed & Wake: possibly include non-wear data"))					
		}
		if(lgnd==TRUE) legend("topleft", lgd2, bty="n", cex=.8)
		
	}
	
}
	

